@@ -20,6 +20,13 @@ def includeme(config):
         '/clientlogs/batch',
         request_method='POST',
         )
+    # added a new route so that flash-logging clients can use
+    # the same URL endpoint for both simple and batch logs
+    config.add_route(
+        'clientlogs_batch_flexible',
+        '/clientlogs/',
+        request_method='POST',
+        )
     config.scan('pyramid_restlogging.views')
     config.commit()
 
